#
# spec file for package gwenview5
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define rname gwenview
%define kf5_version 5.105.0
%bcond_without released
Name:           gwenview5
Version:        23.08.2
Release:        1.1
Summary:        Image Viewer by KDE
License:        GPL-2.0-or-later
URL:            https://apps.kde.org/gwenview
Source:         https://download.kde.org/stable/release-service/%{version}/src/%{rname}-%{version}.tar.xz
%if %{with released}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{rname}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
BuildRequires:  cfitsio-devel
BuildRequires:  extra-cmake-modules >= %{kf5_version}
BuildRequires:  kf5-filesystem
BuildRequires:  libexiv2-devel
BuildRequires:  libjpeg-devel
BuildRequires:  liblcms2-devel
BuildRequires:  libpng-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Activities)
BuildRequires:  cmake(KF5Baloo)
BuildRequires:  cmake(KF5DocTools)
BuildRequires:  cmake(KF5GuiAddons)
BuildRequires:  cmake(KF5I18n)
BuildRequires:  cmake(KF5IconThemes)
BuildRequires:  cmake(KF5ItemModels)
BuildRequires:  cmake(KF5KDcraw)
BuildRequires:  cmake(KF5KIO)
BuildRequires:  cmake(KF5Kipi)
BuildRequires:  cmake(KF5Notifications)
BuildRequires:  cmake(KF5Parts)
BuildRequires:  cmake(KF5Purpose)
BuildRequires:  cmake(KF5WindowSystem)
BuildRequires:  cmake(Phonon4Qt5)
BuildRequires:  cmake(Qt5Concurrent)
BuildRequires:  cmake(Qt5Core)
BuildRequires:  cmake(Qt5DBus)
BuildRequires:  cmake(Qt5OpenGL)
BuildRequires:  cmake(Qt5PrintSupport)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5WaylandClient)
BuildRequires:  cmake(Qt5X11Extras)
BuildRequires:  cmake(kImageAnnotator)
BuildRequires:  cmake(kColorPicker)
BuildRequires:  pkgconfig(libtiff-4)
BuildRequires:  pkgconfig(wayland-protocols)
BuildRequires:  libqt5-qtbase-private-headers-devel
%requires_ge    libQt5Core5
Provides:       gwenview = %{version}
Obsoletes:      gwenview < %{version}

%description
Gwenview is an image viewer by KDE. It features a folder tree window and a file
list window, providing navigation of file hierarchies.

%lang_package

%prep
%autosetup -p1 -n %{rname}-%{version}

%build
%cmake_kf5 -d build -- -DGWENVIEW_SEMANTICINFO_BACKEND="Baloo"
%cmake_build

%install
%kf5_makeinstall -C build

%find_lang %{name} --with-man --all-name
%{kf5_find_htmldocs}

%suse_update_desktop_file -r org.kde.gwenview Graphics RasterGraphics Viewer KDE

%ldconfig_scriptlets

%files
%license COPYING*
%dir %{_kf5_plugindir}/kf5
%dir %{_kf5_plugindir}/kf5/kfileitemaction
%dir %{_kf5_plugindir}/kf5/parts
%dir %{_kf5_sharedir}/kconf_update/
%dir %{_kf5_sharedir}/solid
%dir %{_kf5_sharedir}/solid/actions
%doc %lang(en) %{_kf5_htmldir}/en/gwenview/
%{_kf5_applicationsdir}/org.kde.gwenview.desktop
%{_kf5_applicationsdir}/org.kde.gwenview_importer.desktop
%{_kf5_appstreamdir}/org.kde.gwenview.appdata.xml
%{_kf5_bindir}/gwenview
%{_kf5_bindir}/gwenview_importer
%{_kf5_debugdir}/gwenview.categories
%{_kf5_iconsdir}/hicolor/*/*/*
%{_kf5_libdir}/libgwenviewlib.so.*
%{_kf5_plugindir}/kf5/kfileitemaction/slideshowfileitemaction.so
%{_kf5_plugindir}/kf5/parts/gvpart.so
%{_kf5_servicesdir}/gvpart.desktop
%{_kf5_sharedir}/gwenview/
%{_kf5_sharedir}/kconf_update/gwenview-imageview-alphabackgroundmode-update.pl
%{_kf5_sharedir}/kconf_update/gwenview.upd
%{_kf5_sharedir}/solid/actions/gwenview_*.desktop

%files lang -f %{name}.lang

%changelog
* Tue Oct 10 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.2/
- No code change since 23.08.1
* Tue Sep 12 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.1/
- Changes since 23.08.0:
  * Fix navigation with side mouse buttons
  * Stop overriding settings menu (kde#473672)
  * Don't mark two English strings as untranslated (kde#473637)
* Sun Aug 20 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.08.0/
- No code change since 23.07.90
* Mon Aug 14 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.90
  * New feature release
- Changes since 23.07.80:
  * Make image switching seamless when animations are disabled (kde#472351)
  * Delay showing loading indicator
* Tue Aug  1 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.07.80
  * New feature release
- Changes since 23.04.3:
  * Add new format commit to ignore list
  * Run clang-format
  * Don't ignore the second of two fast middle-clicks to toggle zoom
  * Fix KActivities and Purpose detection in KF6
  * Pass exivData as argument to avoid crash in exiv2 library (kde#470880)
  * Use non-deprecated Phonon includes
  * Fix color management settings (kde#468706)
  * Adapt to KIconThemes changes
  * Fix build with exiv2 >= 0.28
  * Fix running wrong application in 'Open with...' menu (kde#469824)
  * Add an action to open in a new window (kde#469179)
  * Add wayland to third-party deps
  * ZoomComboBox: improve autocomplete
  * Update AppData file's features list to reflect recent changes
  * ZoomComboBox: use fuzzy comparing for qreal
  * Remove "Delete" and "Create Folder" actions from sidebar (kde#458987)
  * Don't set the default icon size for KFilePlacesView in *.ui file (kde#468755)
  * ZoomSlider: directly zoom instead of page step on left click
  * Improve ZoomComboBox
  * Don't show Gwenview in its own "Open With" menu (kde#462088)
  * Inhibit screen locking and sleep only when the app is in the foreground (kde#386517)
  * Adapt to KF6 KParts change
  * Save a shallow copy of the original image when rotating (kde#439697)
  * flatpak: Use v5.104.0 tag for baloo frameworks
  * flatpak: Fix whitespace
  * Make it build against KF6
  * Don't strip away scheme for non-local URLs in window title
* Tue Jul  4 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.3/
- Changes since 23.04.2:
  * Pass exivData as argument to avoid crash in exiv2 library (kde#470880)
* Tue Jun  6 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.2/
- Changes since 23.04.1:
  * Fix build with exiv2 >= 0.28
  * Fix running wrong application in 'Open with...' menu (kde#469824)
* Tue May  9 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.1/
- Changes since 23.04.0:
  * Don't set the default icon size for KFilePlacesView in *.ui file (kde#468755)
  * Don't show Gwenview in its own "Open With" menu (kde#462088)
* Sat Apr 15 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/23.04.0/
* Fri Mar 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.90
  * New feature release
* Fri Mar 17 2023 Christophe Marin <christophe@krop.fr>
- Update to 23.03.80
  * New feature release
* Tue Feb 28 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.3/
* Tue Jan 31 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.2/
* Tue Jan  3 2023 Christophe Marin <christophe@krop.fr>
- Update to 22.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.1/
* Fri Dec  2 2022 Christophe Marin <christophe@krop.fr>
- Update to 22.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.12.0/
* Sat Nov 26 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.90
  * New feature release
* Sat Nov 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.11.80
  * New feature release
* Tue Nov  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.3/
* Tue Oct 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.2/
* Tue Sep  6 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.1/
* Sun Aug 14 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.08.0/
* Fri Aug  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.90
  * New feature release
* Sat Jul 16 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.07.80
  * New feature release
* Tue Jul  5 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.3/
* Wed Jun  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.2/
* Tue May 10 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.1/
* Mon Apr 18 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/22.04.0/
* Fri Apr  8 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.90
  * New feature release
* Wed Mar 23 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 22.03.80
  * New feature release
- Too many changes since 21.12.3, only listing bugfixes:
  * Add a "Fit" button to the status bar (kde#441447)
  * Fix Bug 445434: Gwenview crash when clicking "crop"
    button (kde#445434)
  * Add proper desktop file for importer (kde#446290)
  * Use normal font size for sidebar text (kde#447287)
  * Only switch to Qt::FastTransformation ("showing pixels")
    at 500%% zoom (kde#443010)
  * Add "Print Preview" action (kde#236056)
* Tue Mar  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.3/
- Changes since 21.12.2:
  * Prevent users from "losing" the thumbnail bar
* Tue Feb  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.2/
- Changes since 21.12.1:
  * Revert "Prefer mime type from content over file name when loading" (kde#441698)
  * Guard against null QScreen (kde#442424)
* Tue Jan  4 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.1/
- Changes since 21.12.0:
  * catch std::out_of_range exception from libexiv2
  * Fix scrolling on the ZoomComboBox
* Fri Dec  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.12.0/
- No code change since 21.11.90
* Sat Nov 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.90
  * New feature release
- Changes since 21.11.80:
  * Auto set print orientation
* Sat Nov 13 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.11.80
  * New feature release
- Changes since 21.08.3:
  * Use action verb for button to show and hide the thumbnail bar (kde#445203)
  * Show estimated file size in the resize image dialog (kde#433740)
  * Use qAsConst
  * Fix some clazy warning
  * [ZoomComboBox] Don't switch to Browse mode by pressing Esc while the popup is visible
  * [ZoomComboBox] Override showPopup instead of mousePressEvent
  * Convert image to original format to enable correct color correction
  * Don't change the zoom value unless the user made a selection (kde#441004)
  * Allow typing a zoom level in the zoom combo
  * Add KDE CI file
  * icons: Update to latest Breeze version
  * icons: Remove old application & action icons
  * Remove duplicate includes between .cpp/.h
  * Clean up unneeded JSON parameter in kcoreaddons_add_plugin
  * Use QDialog::show() instead of exec()
  * Port to KXMLGUIFactory::showConfigureShortcutsDialog()
  * Add clang-format bits to CMakeLists.txt
* Tue Nov  2 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.3/
- No code change since 21.08.2
* Tue Oct  5 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.2/
- Changes since 21.08.1:
  * Restore the ability to quickly switch between "Zoom to Fit" and "Actual
    Size" with a keyboard shortcut (kde#441152)
* Wed Sep  1 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.1
- No code change since 21.08.0
* Fri Aug  6 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.08.0
- No code change since 21.07.90
* Fri Jul 30 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.90
  * New feature release
- Changes since 21.07.80:
  * Add catalog definition for Dolphin context menu items (kde#439931)
* Sat Jul 17 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.07.80
  * New feature release
- Too many changes since 21.04.3, only listing bugfixes:
  * Don't correct zoom level for hidpi, instead correct target rectangle (kde#438125)
  * Add tooltip for "save all" button after editing image (kde#433387)
  * Add "Copy" items to context menus (kde#437264)
  * Use a simple QGraphicsItem subclass for drawing raster images (kde#271671)
  * InfoContextManagerItem: use indent not contentMargins for indenting, change
    text and position of "More...", adjust margins, change title (kde#431627)
  * Prefer mime type from content over file name when loading (kde#329140)
  * Set status bar size constraint to fixed size (kde#434786)
- Only install the license files once
* Wed Jul  7 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.3
- No code change since 21.04.2
* Tue Jun  8 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04.2
- No code change since 21.04.1
* Wed May 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/21.04.1
- Changes since 21.04.0:
  * List image/avif among supported mimetypes
* Fri Apr 16 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/gear/21.04
- No code change since 21.03.90
- Stop owning directories provided by the filesystem package (boo#1184786)
* Fri Apr  9 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.90
  * New feature release
- Changes since 21.03.80:
  * Partially revert commit "Use Quality level when saving JPEG images"
  * Set a sane default window size
* Sun Mar 21 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 21.03.80
  * New feature release
- Too many changes since 20.12.3, only listing bugfixes:
  * When receiving a list of files as parameters, filter duplicate filenames (kde#434046)
  * Base scroll speed on text height rather than image row height (kde#297853)
  * Show quality chooser for other lossy image formats too (kde#431680)
  * Replace slideshow ServiceMenu by SlideShowFileItemAction (kde#429531)
  * Allow disabling Bird's Eye View (kde#426105)
  * Fix zoom with F or middle mouse click caused by the introduction of the spinbox (kde#432075)
  * VideoViewAdapter: Show video timestamps (kde#414769)
  * Enable custom zoom values with a SpinBox replacing the static label (kde#157274)
- Enable libtiff support
* Thu Mar  4 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/20.12.3
- Changes since 20.12.2:
  * Switch from QGLWidget to QOpenGLWidget (kde#403323)
  * Use Quality level when saving JPEG images
* Wed Feb  3 2021 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-02-apps-update
- Changes since 20.12.1:
  * Fix visual artifacts when panning zoomed in image on HiDPI (kde#417342)
* Tue Jan  5 2021 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2021-01-apps-update
- Changes since 20.12.0:
  * Do not restore the JPG quality after a "Save" operation
* Sat Dec  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.12.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-12-apps-update
- No code change since 20.11.90
* Fri Nov 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.90
  * New feature release
- No code change since 20.11.80
* Sat Nov 14 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.11.80
  * New feature release
- Too many changes since 20.08.3, only listing bugfixes:
  * Show message bar with URL after sharing to imgur (kde#428528)
  * Add option to disable autoplaying videos (kde#274901)
  * Fix ESC key not exiting fullscreen when viewing image (kde#425479)
* Thu Nov  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-11-apps-update
- Changes since 20.08.2:
  * Fix typo in KIPI plugins URL (kde#421015)
  * Set visibility after setting parent (kde#427569)
* Fri Oct  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-10-apps-update
- Changes since 20.08.1:
  * Fix deadlock when closing gwenview importer (kde#425971)
* Tue Sep  1 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.08.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-09-apps-update
- Changes since 20.08.0:
  * Make "Sort By" menu work properly (kde#425739)
* Sun Aug  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.08.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-08-apps-update
- No code change since 20.07.90
* Sun Aug  2 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.90
  * New feature release
- No code change since 20.07.80
* Sun Jul 19 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.07.80
  * New feature release
- Too many changes since 20.04.3, only listing bugfixes:
  * fix lagging zoom with touch in wayland (kde#405945)
  * Add file overwrite prompt when saving a file (kde#420528)
* Thu Jul  9 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-07-apps-update
- No code change since 20.04.2
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- No code change since 20.04.1
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- No code change since 20.04.0
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- Changes since 20.03.90:
  * Improve responsiveness when showing single image without thumbnail bar
  * Fix hang on exit when viewing huge folder
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- Changes since 20.03.80:
  * Fix jpeg save quality
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Too many changes since 19.12.3, only listing bugfixes:
  * Give Exit Full Screen and Configure buttons text and adjust wording (kde#385314)
  * Setup paste action text before main loop starts (kde#411196)
  * Add button to toggle sidebar in fullscreen mode (kde#414694)
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- Changes since 19.12.2:
  * Fix loading of remote files (i.e https)
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- Changes since 19.12.1:
  * Fix divide-by-zero crash (kde#414631)
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- Changes since 19.12.0:
  * Update Appstream for new release
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- Changes since 19.11.90:
  * Update Appstream for new release
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- No code change since 19.11.80
* Sun Nov 24 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * New feature release
- Too many changes since 19.08.3, only listing bugfixes:
  * Create additional subfolders if needed (e.g. when extra slashes in FileNameFormater). (kde#237114)
  * fix fractional scaling (kde#412738)
* Thu Nov  7 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.3.php
- No code change since 19.08.2
* Fri Oct 11 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.2.php
- Changes since 19.08.1:
  * Save the Mimetype of opened resources
* Thu Sep  5 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.1.php
- No code change since 19.08.0
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- No code change since 19.07.90
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- No code changes since 19.07.80
* Tue Jul 23 2019 lbeltrame@kde.org
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 19.04.3:
  * Too many changes to list here
* Sat Jul 13 2019 lbeltrame@kde.org
- Update to 19.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.3.php
- No code changes since 19.04.2
* Fri Jun  7 2019 lbeltrame@kde.org
- Update to 19.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.2.php
- Changes since 19.04.1:
  * Fix build with exiv2-0.27.1
* Fri May 10 2019 lbeltrame@kde.org
- Update to 19.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.1.php
- No code changes since 19.04.0
* Sat Apr 20 2019 lbeltrame@kde.org
- Update to 19.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.0.php
- Changes since 19.03.90:
  * Add HiDPI support for thumbnails
- Dropped patches, now upstream:
  * 0001-Add-HiDPI-support-for-thumbnails.patch
* Tue Apr  9 2019 lbeltrame@kde.org
- Update to 19.03.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-rc.php
- Changes since 19.03.80:
  * HiDPI Support for Gwenview (kde#373178)
  * Fix -Wreturn-type warning for jpeg version check
- Add upstream patch for HiDPI support in thumbnails (kde#373178):
  * 0001-Add-HiDPI-support-for-thumbnails.patch
* Wed Mar 27 2019 lbeltrame@kde.org
- Update to 19.03.80
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-beta.php
- Changes since 18.12.3:
  * Fix compilation in some systems
  * Touch support for Gwenview
  * Deprecated--
  * Remove deprecated method
  * [MainWindow] Navigate through mouse forward/back buttons
  * Compile tests files with enabled exceptions, required for exiv2 0.27
  * Allow Gwenview to be able to open .kra (Krita) files
  * Set the same image mime types in all desktop files
  * Add mime types for raw image formats to desktop file
  * Create shortcut to focus navigator bar
  * Use semantically correct restoration icon
  * Use user-trash icon for Trash action (kde#391078)
  * Port to new connect api
  * Use Ctrl+i to trigger a name filter, which matches Dolphin (kde#386531)
  * Ignore files
  * Const'ify, add const'ref found by clazy
  * Bump max thumbnail size to 512px
  * Compile more files with enabled exceptions, required for exiv2 0.27
  * Use forward declaration for Exiv2::Image, port to std::unique_ptr
  * Use FlowLayout for Crop toolbar
  * Fix mem leak found by asan
  * [ThumbnailView] Fix mouse buttons handling
- Dropped patches, now upstream:
  * 0001-Compile-more-files-with-enabled-exceptions-required-.patch
  * 0002-Use-forward-declaration-for-Exiv2-Image-port-to-std-.patch
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * No code changes since 18.12.2
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * No code changes since 18.12.1
* Fri Feb  1 2019 wbauer@tmo.at
- Update build requirements
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * No code changes since 18.12.0
* Sat Dec 29 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix build with Exiv2 0.27
  Add 0001-Compile-more-files-with-enabled-exceptions-required-.patch
  Add 0002-Use-forward-declaration-for-Exiv2-Image-port-to-std-.patch
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * Make FindExiv2.cmake work with exiv 0.27.
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * No code changes since 18.11.80
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * Too many changes to list here
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * No code changes since 18.08.2
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * Fix orientation when saving/transforming JPEG images
  * Set file name on print job (kde#332207)
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * Fix Crop tool Aspect ratio sometimes randomly preselected
  * Improve keyboard handling for focused buttons in Crop and Reduce Red Eye tools
  * Fix Advanced settings crop toolbar sometimes cut off
  * Keep the width of the crop spinboxes fixed to avoid wiggling
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * Fix video controls volume slider not vertically centered sometimes (kde#390929)
  * Disable setImageData for dragging of unmodified images
  * Make sure, a newly saved image is selected in ContextManager
  * Keep crop handles inside selection rectangle
  * Remove crosshair cursor from crop tool
  * Fix crosshair cursor not showing in red eye reduction tool (kde#321933)
  * Propagate unused mouse press events in edit tools
  * Reactivate size slider in Red Eye Reduction tool
  * Propagate unused mouse wheel events in edit tools
  * Fix image smoothing sometimes not getting applied (kde#396736)
* Sat Jul 28 2018 wbauer@tmo.at
- Build with gcc7 on Leap 42.3, it doesn't compile with 4.8 anymore
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * Too many changes to list here
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * Fix external application menu occasionally slowing down startup (kde#395925)
  * Fix issues with cursors and unwanted actions when right-clicking
  * Reset zoom cursor more reliably
  * Fix QFileDialog::selectUrl() setting initial directory
  * Enable AutoErrorHandling for rename job (kde#395890)
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * Fix share menu not showing the first time it is used
  * Watch for installation of kipi-plugins only when needed
  * Update thumbnail de-/select hover button on selection change (kde#394406)
  * Update paste action on current directory and selection changes (kde#276255)
  * Cleanup code for finishing undo/redo of image operations
  * Enable redo for undone image operations
  * Disable View mode shortcuts outside of View mode
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * Fix custom folder icons using an absolute path entry (kde#315983)
  * Fix "Save As" in failed-save message box
  * Remove duplicate overwrite confirmation dialog
  * Fix duplicate and markup displaying failed-save message box (kde#393170)
  * Fix View Mode session restore (kde#393176)
  * Update view offset in higher zoom levels after image size changed
  * Center image after edit operation changed size
  * Fix reloading of SVG images (kde#359736)
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * Update view offset in higher zoom levels after image size changed
  * Center image after edit operation changed size
  * Fix reloading of SVG images (kde#359736)
  * Adapt PlaceTreeModelTest autotest to KIO change
  * Fix shortcut config changes sometimes not updating until restart (kde#389331)
  * Fix thumbnail update after undo (kde#356998)
  * Fix thumbnail bar update after editing a viewed image
* Fri Apr  6 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04-rc.php
- Changes since 17.12.3:
  * Too many changes to list here
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * Enlarge small SVGs too (kde#364822)
  * Fix URL Navigator margins
  * Hide fullscreen thumbnailbar when on-canvas image tools are in use
  * Remove symbolic icons in favor of standard icons
  * Fix thumbnail bar in View resetting to OFF when quitting in fullscreen
  * Fix background color for image view toolbar (crop/red-eye)
  * Update filename in fullscreen view on rename (kde#390332)
  * Add icons for context and sidebar menu
  * Improve thumbnail tooltip animation (kde#245091)
  * Save config when opening the config dialog (kde#390331)
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * Resize top bar in fullscreen view mode on toggling sidebar (kde#387784)
  * Disable auto saving window size in fullscreen mode
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * Fix failing PlaceTreeModelTest autotest (kde#387824)
  * Respect custom filename for Copy/Move/Link To operations (kde#388144)
  * Fix displaying RW2 files with shared-mime-info 1.9
  * Fix expanding of baloo URLs in folders sidebar tree view
  * Revert changes caused by mistake from previous commit
  * Fixed places side panel for baloo urls
  * Update titlebar after image modification (kde#345980)
  * Correct margin for left sidebar (kde#381535)
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * Update selection after renaming a file (kde#249001)
  * appdata: update doc URL, more https
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * General HiDPI enablement for Gwenview's importer
  * Initial focus to thumbnails in browse mode (kde#312631)
  * Indicate that Gwenview can open Targa images
  * Persist path for "Copy/Move/Link To" to config file
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * Remove stray todo from gvpart.desktop
  * Try to keep ContextManager in sync with viewed files in MainWindow (kde#355493, kde#275807, kde#326190, kde#306835)
  * Make CFitsio optional
  * Update move/copy/link dialog window's title to reflect selected files
  * Fix zoom slider toolbuttons not disabling properly
  * Scroll wheel and touchpad zoom in smaller increments (kde#307637)
  * Add option to show file in File Manager
  * Apply full screen color scheme also to window decoration
  * Remove references to Android and KStars from CMake
  * Fix build with cfitsio
  * Add FITS format support
  * Add ccache support
  * Always show image rotation buttons in Image Operations sidebar when other operations are available (kde#354149)
  * Give Gwenview's Save As dialog a proper title: "Save Image" (kde#348221)
  * Fix CMake CMP0048 warning about project() without VERSION
  * Add .arcconfig
  * Replaced calls to the deprecated function KJobUiDelegate *ui().
  * Look at to use gwenview without install it
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * Fix padding of "Fit Width" button (kde#385035)
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * Fix icon colors of inline context buttons also in full screen mode
  * Use standard QToolButtons so that their icons use the right colors (kde#383059)
  * Gwenview: suppressed unused interface variables compiler warnings.
  * Fix Gwenview Importer doesn't use date/time from EXIF
  * Reduce hyper-sensitive touchpad scroll-zoom speed (kde#378584)
  * Add 16:9 crop preset to Gwenview (kde#364007)
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * Remember paths for Copy-To and Move-To (kde#362474)
* Sat Aug 12 2017 jengelh@inai.de
- Make description neutral.
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
  * Fix assert with Qt debug builds (kde#382542)
  * thumbnailprovider: downgrade missing size info debug from warning, kio doesn't store size info so it spams a lot
  * Use Q_DECL_OVERRIDE
  * Add toolbar menu entries
  * Port more deprecated functions and fix warnings
  * Support Apple OS X' image/x-icns
  * Fix part loading under kpartloader
  * Set organization domain to kde.org.
  * Do not set application data twice. It ends up in desktop file name being org.kde.org.kde.gwenview.
  * Add Fit to width
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.08-rc.php
* Sat Jul 15 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * None
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * Fix Enter and Escape keys in tool dialogs (crop, red eye) (kde#313806)
  * Fixed persistence of "Show Status Bar" action status
  * Add keyboard shortcut for statusbar toggling option
  * Re-enable all tests
  * Fix crop region size (kde#340459)
  * Re-enable importertest
  * Avoid data loss when importing pictures (kde#379615)
- Drop upstreamed patches:
  * fix-importer.patch
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * History (recentfolders) not working / folder never created (kde#379177)
  * Correctly load the translations
* Thu May 11 2017 wbauer@tmo.at
- Add fix-importer.patch to make the importer work and not cause
  data loss if "Delete" is chosen after the import (kde#379615)
- Provides/Obsoletes gwenview instead of Conflicts
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * Do not set application data twice. It ends up in desktop file name being org.kde.org.kde.gwenview.
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * None
* Sat Mar 25 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-beta.php
- Changes since 16.12.3:
  * Too many changes to list here
* Thu Mar  9 2017 lbeltrame@kde.org
- Update to 16.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-16.12.3.php
- Changes since 16.12.2:
  * Fix wrong action name for setDefaultShortcut() (kde#355313)
* Thu Feb  9 2017 lbeltrame@kde.org
- Update to KDE Applications 16.12.2
  * KDE Applications 16.12.2
  * https://www.kde.org/announcements/announce-applications-16.12.2.php
* Sat Jan 14 2017 lbeltrame@kde.org
- - Update to KDE Applications 16.12.1
  * KDE Applications 16.12.1
  * https://www.kde.org/announcements/announce-applications-16.12.1.php
* Tue Dec 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.12.0
  * KDE Applications 16.12.0
  * https://www.kde.org/announcements/announce-applications-16.12.0.php
* Sat Dec  3 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.90
  * KDE Applications 16.12.0 RC
  * https://www.kde.org/announcements/announce-applications-16.12-rc.php
* Tue Nov 29 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.11.80
  * KDE Applications 16.12.0 Beta
  * https://www.kde.org/announcements/announce-applications-16.12-beta.php
- Dropped patches:
  + fix-multiple-arguments.diff
* Wed Nov  9 2016 lbeltrame@kde.org
- Update to KDE Applications 16.08.3
  * KDE Applications 16.08.3
  * https://www.kde.org/announcements/announce-applications-16.08.3.php
* Tue Oct 11 2016 lbeltrame@kde.org
- KDE Applications 16.08.2
  https://www.kde.org/announcements/announce-applications-16.08.2.php
* Thu Sep 29 2016 alarrosa@suse.com
- Added a require for kdelibs4support since that package provides
  qimageioplugins services for jpeg, png, gif and other image formats
  and gwenview5 can't be used without it (boo#1001276).
* Wed Sep 28 2016 alarrosa@suse.com
- Added QUrl::AssumeLocalFile to fix-multiple-arguments.diff to
  mimic the patch accepted upstream
* Wed Sep 28 2016 alarrosa@suse.com
- Add fix-multiple-arguments.diff to fix handling of multiple local
  file arguments in the command line (boo#1001276)
* Fri Sep  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.1
  * KDE Applications 16.08.1
  * https://www.kde.org/announcements/announce-applications-16.08.1.php
* Fri Aug 12 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.08.0
  * KDE Applications 16.08.0
  * https://www.kde.org/announcements/announce-applications-16.08.0.php
* Mon Aug  8 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.07.90
  * KDE Applications 16.07.90 (16.08-RC)
  * https://www.kde.org/announcements/announce-applications-16.08-rc.php
* Thu Jul  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.3
  * KDE Applications 16.04.3
  * https://www.kde.org/announcements/announce-applications-16.04.3.php
* Fri Jun 10 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.2
  * KDE Applications 16.04.2
  * https://www.kde.org/announcements/announce-applications-16.04.2.php
* Sat May  7 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.1
  * KDE Applications 16.04.1
  * https://www.kde.org/announcements/announce-applications-16.04.1.php
* Sun Apr 17 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.04.0
  * KDE Applications 16.04.0
  * https://www.kde.org/announcements/announce-applications-16.04.0.php
* Mon Apr 11 2016 tittiatcoke@gmail.com
- Update to KDE Applications 16.03.90
  * KDE Applications 16.04.0 RC
  * https://www.kde.org/announcements/announce-applications-16.04-rc.php
* Sun Mar 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.3
  * KDE Applications 15.12.3
  * https://www.kde.org/announcements/announce-applications-15.12.3.php
  * boo#970855
* Sat Feb 13 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.2
  * KDE Applications 15.12.2
  * https://www.kde.org/announcements/announce-applications-15.12.2.php
  * boo#966605
* Sat Jan  9 2016 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.1
  * KDE Applications 15.12.1
  * https://www.kde.org/announcements/announce-applications-15.12.1.php
  * boo#961265
* Sun Dec 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.12.0
  * KDE Applications 15.12.0
  * https://www.kde.org/announcements/announce-applications-15.12.0.php
  * boo#958887
* Tue Nov 10 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.3
  * KDE Applications 15.08.3
  * https://www.kde.org/announcements/announce-applications-15.08.3.php
  * boo#954531
* Sun Oct 18 2015 hrvoje.senjan@gmail.com
- Let gwenview5 be installable
* Sun Oct 11 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.2
  * KDE Applications 15.08.2
  * https://www.kde.org/announcements/announce-applications-15.08.2.php
* Sun Sep 13 2015 tittiatcoke@gmail.com
- Update to KDE Applications 15.08.1
  * KDE Applications 15.08.1
  * https://www.kde.org/announcements/announce-applications-15.08.1.php
* Sat Aug 22 2015 cgiboudeaux@gmx.com
- Initial package for Gwenview.
